# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# DryRun operation. A request will not be successful if the `DryRun` parameter is passed in.
DRYRUNOPERATION = 'DryRunOperation'

# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# Failed to manipulate the AI API.
FAILEDOPERATION_AITRANSCODEOPTIONFAIL = 'FailedOperation.AiTranscodeOptionFail'

# Failed to change the task status.
FAILEDOPERATION_ALTERTASKSTATE = 'FailedOperation.AlterTaskState'

# Failed to call the third-party service.
FAILEDOPERATION_CALLOTHERSVRERROR = 'FailedOperation.CallOtherSvrError'

# Failed to call the internal service.
FAILEDOPERATION_CALLOTHERSVRFAILED = 'FailedOperation.CallOtherSvrFailed'

# The canceled stream mix session does not exist.
FAILEDOPERATION_CANCELSESSIONNOTEXIST = 'FailedOperation.CancelSessionNotExist'

# The template is in use.
FAILEDOPERATION_CONFINUSED = 'FailedOperation.ConfInUsed'

# The domain name cannot be deleted because it incurred traffic in the last 2 days and is in locked state.
FAILEDOPERATION_DELETEDOMAININLOCKEDTIME = 'FailedOperation.DeleteDomainInLockedTime'

# Failed to configure the domain rule.
FAILEDOPERATION_DOMAINGSLBFAIL = 'FailedOperation.DomainGslbFail'

# Unable to get the watermark URL.
FAILEDOPERATION_GETPICTUREURLERROR = 'FailedOperation.GetPictureUrlError'

# Failed to get the input stream length and width.
FAILEDOPERATION_GETSTREAMRESOLUTIONERROR = 'FailedOperation.GetStreamResolutionError'

# No live stream.
FAILEDOPERATION_HASNOTLIVINGSTREAM = 'FailedOperation.HasNotLivingStream'

# The number of domain names exceeded the upper limit (100).
FAILEDOPERATION_HOSTOUTLIMIT = 'FailedOperation.HostOutLimit'

# An exception occurred while manipulating the VOD API.
FAILEDOPERATION_INVOKEVIDEOAPIFAIL = 'FailedOperation.InvokeVideoApiFail'

# The billing platform returned an error of insufficient balance.
FAILEDOPERATION_JIFEINOENOUGHFUND = 'FailedOperation.JiFeiNoEnoughFund'

# No records found.
FAILEDOPERATION_NOTFOUND = 'FailedOperation.NotFound'

# Failed to start stream mix.
FAILEDOPERATION_PROCESSMIXERROR = 'FailedOperation.ProcessMixError'

# Failed to query the upload information.
FAILEDOPERATION_QUERYUPLOADINFOFAILED = 'FailedOperation.QueryUploadInfoFailed'

# The rule already exists.
FAILEDOPERATION_RULEALREADYEXIST = 'FailedOperation.RuleAlreadyExist'

# The user has no valid traffic package.
FAILEDOPERATION_SDKNOPACKAGE = 'FailedOperation.SdkNoPackage'

# The stream does not exist.
FAILEDOPERATION_STREAMNOTEXIST = 'FailedOperation.StreamNotExist'

# Failed to unbind the tag. Try unbinding it manually.
FAILEDOPERATION_TAGUNBINDERROR = 'FailedOperation.TagUnbindError'

# Internal error.
INTERNALERROR = 'InternalError'

# For the transcoding template adding API.
INTERNALERROR_ARGSNOTMATCH = 'InternalError.ArgsNotMatch'

# Error calling internal service.
INTERNALERROR_CALLOTHERSVRERROR = 'InternalError.CallOtherSvrError'

# Chinese domain names are not supported currently. Please check the domain name format.
INTERNALERROR_CHINESECHARACTERDETECTED = 'InternalError.ChineseCharacterDetected'

# The template is in use.
INTERNALERROR_CONFINUSED = 'InternalError.ConfInUsed'

# The template does not exist.
INTERNALERROR_CONFNOTFOUND = 'InternalError.ConfNotFound'

# The number of templates exceeded the limit.
INTERNALERROR_CONFOUTLIMIT = 'InternalError.ConfOutLimit'

# The configuration does not exist.
INTERNALERROR_CONFIGNOTEXIST = 'InternalError.ConfigNotExist'

# Database connection error.
INTERNALERROR_CONNECTDBERROR = 'InternalError.ConnectDbError'

# The certificate is in use.
INTERNALERROR_CRTDATEINUSING = 'InternalError.CrtDateInUsing'

# The certificate does not exist.
INTERNALERROR_CRTDATENOTFOUND = 'InternalError.CrtDateNotFound'

# The certificate is invalid.
INTERNALERROR_CRTDATENOTLEGAL = 'InternalError.CrtDateNotLegal'

# The certificate has expired.
INTERNALERROR_CRTDATEOVERDUE = 'InternalError.CrtDateOverdue'

# There is no related domain name.
INTERNALERROR_CRTDOMAINNOTFOUND = 'InternalError.CrtDomainNotFound'

# The certificate key does not match.
INTERNALERROR_CRTKEYNOTMATCH = 'InternalError.CrtKeyNotMatch'

# DB execution error.
INTERNALERROR_DBERROR = 'InternalError.DBError'

# The domain name is already connected elsewhere. Please check whether the entered domain name is correct, and if yes, you can add it again after successful ownership verification.
INTERNALERROR_DOMAINALREADYEXIST = 'InternalError.DomainAlreadyExist'

# The domain name format is incorrect. Please enter a valid one.
INTERNALERROR_DOMAINFORMATERROR = 'InternalError.DomainFormatError'

# Failed to add the GSLB rule.
INTERNALERROR_DOMAINGSLBFAIL = 'InternalError.DomainGslbFail'

# The domain name is already connected elsewhere. Please check whether the entered domain name is correct, and if yes, you can add it again after successful ownership verification.
INTERNALERROR_DOMAINISFAMOUS = 'InternalError.DomainIsFamous'

# Your domain name is unavailable. Please enter a correct domain name.
INTERNALERROR_DOMAINISLIMITED = 'InternalError.DomainIsLimited'

# The domain name has no ICP filing.
INTERNALERROR_DOMAINNORECORD = 'InternalError.DomainNoRecord'

# The domain name does not exist.
INTERNALERROR_DOMAINNOTEXIST = 'InternalError.DomainNotExist'

# The domain name length exceeds the limit.
INTERNALERROR_DOMAINTOOLONG = 'InternalError.DomainTooLong'

# Error getting user account.
INTERNALERROR_GETBIZIDERROR = 'InternalError.GetBizidError'

# Error getting the configuration.
INTERNALERROR_GETCONFIGERROR = 'InternalError.GetConfigError'

# Failed to get the stream information.
INTERNALERROR_GETSTREAMINFOERROR = 'InternalError.GetStreamInfoError'

# Error getting the live stream source information.
INTERNALERROR_GETUPSTREAMINFOERROR = 'InternalError.GetUpstreamInfoError'

# An error occurred while getting the watermark.
INTERNALERROR_GETWATERMARKERROR = 'InternalError.GetWatermarkError'

# No live stream.
INTERNALERROR_HASNOTLIVINGSTREAM = 'InternalError.HasNotLivingStream'

# Parameter check failed.
INTERNALERROR_INVALIDINPUT = 'InternalError.InvalidInput'

# Invalid request.
INTERNALERROR_INVALIDREQUEST = 'InternalError.InvalidRequest'

# Account information error.
INTERNALERROR_INVALIDUSER = 'InternalError.InvalidUser'

# The billing platform returned other errors.
INTERNALERROR_JIFEIOTHERERROR = 'InternalError.JiFeiOtherError'

# Internal network error.
INTERNALERROR_NETWORKERROR = 'InternalError.NetworkError'

# The record does not exist.
INTERNALERROR_NOTFOUND = 'InternalError.NotFound'

# No permission to operate.
INTERNALERROR_NOTPERMMITOPERAT = 'InternalError.NotPermmitOperat'

# The playback domain name does not exist.
INTERNALERROR_PLAYDOMAINNORECORD = 'InternalError.PlayDomainNoRecord'

# The transcoding template name already exists.
INTERNALERROR_PROCESSORALREADYEXIST = 'InternalError.ProcessorAlreadyExist'

# The push domain name does not exist.
INTERNALERROR_PUSHDOMAINNORECORD = 'InternalError.PushDomainNoRecord'

# Failed to query the playback information by ISP and district.
INTERNALERROR_QUERYPROISPPLAYINFOERROR = 'InternalError.QueryProIspPlayInfoError'

# Failed to query the upload information.
INTERNALERROR_QUERYUPLOADINFOFAILED = 'InternalError.QueryUploadInfoFailed'

# The rule has already been configured.
INTERNALERROR_RULEALREADYEXIST = 'InternalError.RuleAlreadyExist'

# The rule is in use.
INTERNALERROR_RULEINUSING = 'InternalError.RuleInUsing'

# The rule does not exist.
INTERNALERROR_RULENOTFOUND = 'InternalError.RuleNotFound'

# The rule exceeds the limit.
INTERNALERROR_RULEOUTLIMIT = 'InternalError.RuleOutLimit'

# Exceptional stream status.
INTERNALERROR_STREAMSTATUSERROR = 'InternalError.StreamStatusError'

# Internal system error.
INTERNALERROR_SYSTEMERROR = 'InternalError.SystemError'

# Failed to update data.
INTERNALERROR_UPDATEDATAERROR = 'InternalError.UpdateDataError'

# Failed to add the watermark.
INTERNALERROR_WATERMARKADDERROR = 'InternalError.WatermarkAddError'

# An internal error occurred while modifying the watermark.
INTERNALERROR_WATERMARKEDITERROR = 'InternalError.WatermarkEditError'

# The watermark does not exist.
INTERNALERROR_WATERMARKNOTEXIST = 'InternalError.WatermarkNotExist'

# Invalid parameter.
INVALIDPARAMETER = 'InvalidParameter'

# Incorrect template name.
INVALIDPARAMETER_ARGSNOTMATCH = 'InvalidParameter.ArgsNotMatch'

# Incorrect custom COS filename.
INVALIDPARAMETER_COSCUSTOMFILENAMEERROR = 'InvalidParameter.COSCustomFileNameError'

# The canceled session does not exist.
INVALIDPARAMETER_CANCELSESSIONNOTEXIST = 'InvalidParameter.CancelSessionNotExist'

# Incorrect Tencent Cloud-hosted certificate ID.
INVALIDPARAMETER_CLOUDCRTIDERROR = 'InvalidParameter.CloudCrtIdError'

# The gifted Tencent Cloud domain name has expired.
INVALIDPARAMETER_CLOUDDOMAINISSTOP = 'InvalidParameter.CloudDomainIsStop'

# The certificate is in use.
INVALIDPARAMETER_CRTDATEINUSING = 'InvalidParameter.CrtDateInUsing'

# The certificate is invalid.
INVALIDPARAMETER_CRTDATENOTLEGAL = 'InvalidParameter.CrtDateNotLegal'

# The certificate has expired.
INVALIDPARAMETER_CRTDATEOVERDUE = 'InvalidParameter.CrtDateOverdue'

# The certificate key does not match.
INVALIDPARAMETER_CRTKEYNOTMATCH = 'InvalidParameter.CrtKeyNotMatch'

# The certificate content or private key was not provided.
INVALIDPARAMETER_CRTORKEYNOTEXIST = 'InvalidParameter.CrtOrKeyNotExist'

# The domain name already exists.
INVALIDPARAMETER_DOMAINALREADYEXIST = 'InvalidParameter.DomainAlreadyExist'

# The domain name format is incorrect. Please enter a valid one.
INVALIDPARAMETER_DOMAINFORMATERROR = 'InvalidParameter.DomainFormatError'

# This domain name is on the blocklist.
INVALIDPARAMETER_DOMAINHITBLACKLIST = 'InvalidParameter.DomainHitBlackList'

# A blocklisted domain name is used.
INVALIDPARAMETER_DOMAINISFAMOUS = 'InvalidParameter.DomainIsFamous'

# The domain name is restricted. Please submit a ticket for application to remove the restrictions.
INVALIDPARAMETER_DOMAINISLIMITED = 'InvalidParameter.DomainIsLimited'

# The domain name exceeds the length limit.
INVALIDPARAMETER_DOMAINTOOLONG = 'InvalidParameter.DomainTooLong'

# The number of inputs exceeds the limit.
INVALIDPARAMETER_INPUTNUMLIMITEXCEEDED = 'InvalidParameter.InputNumLimitExceeded'

# Invalid background length and width.
INVALIDPARAMETER_INVALIDBACKGROUDRESOLUTION = 'InvalidParameter.InvalidBackgroudResolution'

# Invalid output bitrate.
INVALIDPARAMETER_INVALIDBITRATE = 'InvalidParameter.InvalidBitrate'

# Invalid callback URL.
INVALIDPARAMETER_INVALIDCALLBACKURL = 'InvalidParameter.InvalidCallbackUrl'

# The cropped area overflows the original image.
INVALIDPARAMETER_INVALIDCROPPARAM = 'InvalidParameter.InvalidCropParam'

# Invalid layer parameter.
INVALIDPARAMETER_INVALIDLAYERPARAM = 'InvalidParameter.InvalidLayerParam'

# The output stream ID is already used.
INVALIDPARAMETER_INVALIDOUTPUTSTREAMID = 'InvalidParameter.InvalidOutputStreamID'

# Invalid output type. Please check whether `OutputPram-StreamId` and `OutputType` match.
INVALIDPARAMETER_INVALIDOUTPUTTYPE = 'InvalidParameter.InvalidOutputType'

# The watermark ID was not set.
INVALIDPARAMETER_INVALIDPICTUREID = 'InvalidParameter.InvalidPictureID'

# Invalid corner radius of the rounded rectangle.
INVALIDPARAMETER_INVALIDROUNDRECTRADIUS = 'InvalidParameter.InvalidRoundRectRadius'

# Invalid source URL.
INVALIDPARAMETER_INVALIDSOURCEURL = 'InvalidParameter.InvalidSourceUrl'

# The time period of the task exceeded the limit.
INVALIDPARAMETER_INVALIDTASKTIME = 'InvalidParameter.InvalidTaskTime'

# Invalid destination URL.
INVALIDPARAMETER_INVALIDTOURL = 'InvalidParameter.InvalidToUrl'

# Incorrect `VodFileName`.
INVALIDPARAMETER_INVALIDVODFILENAME = 'InvalidParameter.InvalidVodFileName'

# 
INVALIDPARAMETER_INVALIDWATERMARK = 'InvalidParameter.InvalidWatermark'

# It is not allowed to add a Mini Program domain name deleted in the same month.
INVALIDPARAMETER_MPHOSTDELETE = 'InvalidParameter.MpHostDelete'

# The WeChat Mini Program plug-in is unauthorized.
INVALIDPARAMETER_MPPLUGINNOUSE = 'InvalidParameter.MpPluginNoUse'

# Other errors.
INVALIDPARAMETER_OTHERERROR = 'InvalidParameter.OtherError'

# The output stream of the same session has changed.
INVALIDPARAMETER_SESSIONOUTPUTSTREAMCHANGED = 'InvalidParameter.SessionOutputStreamChanged'

# The task does not exist.
INVALIDPARAMETER_TASKNOTEXIST = 'InvalidParameter.TaskNotExist'

# The number of tasks reached the limit.
INVALIDPARAMETER_TASKNUMMORETHANLIMIT = 'InvalidParameter.TaskNumMoreThanLimit'

# The template does not match the number of input streams.
INVALIDPARAMETER_TEMPLATENOTMATCHINPUTNUM = 'InvalidParameter.TemplateNotMatchInputNum'

# No permission to access the external URL.
INVALIDPARAMETER_TOURLNOPERMISSION = 'InvalidParameter.ToUrlNoPermission'

# Failed to resolve the domain name.
INVALIDPARAMETER_URLNOTSAFE = 'InvalidParameter.UrlNotSafe'

# Invalid parameter value.
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# Quota exceeded.
LIMITEXCEEDED = 'LimitExceeded'

# The current number of concurrent tasks exceeds the limit.
LIMITEXCEEDED_MAXIMUMRUNNINGTASK = 'LimitExceeded.MaximumRunningTask'

# The number of tasks created on the day exceeds the limit.
LIMITEXCEEDED_MAXIMUMTASK = 'LimitExceeded.MaximumTask'

# Parameter missing.
MISSINGPARAMETER = 'MissingParameter'

# The resource is occupied.
RESOURCEINUSE = 'ResourceInUse'

# Insufficient resources.
RESOURCEINSUFFICIENT = 'ResourceInsufficient'

# The resource is not found.
RESOURCENOTFOUND = 'ResourceNotFound'

# The channel does not exist.
RESOURCENOTFOUND_CHANNELNOTEXIST = 'ResourceNotFound.ChannelNotExist'

# The certificate does not exist.
RESOURCENOTFOUND_CRTDATENOTFOUND = 'ResourceNotFound.CrtDateNotFound'

# No certificate was found.
RESOURCENOTFOUND_CRTDOMAINNOTFOUND = 'ResourceNotFound.CrtDomainNotFound'

# The domain name has no ICP filing.
RESOURCENOTFOUND_DOMAINNORECORD = 'ResourceNotFound.DomainNoRecord'

# The domain name does not exist or is not matched.
RESOURCENOTFOUND_DOMAINNOTEXIST = 'ResourceNotFound.DomainNotExist'

# 
RESOURCENOTFOUND_FORBIDSERVICE = 'ResourceNotFound.ForbidService'

# 
RESOURCENOTFOUND_FREEZESERVICE = 'ResourceNotFound.FreezeService'

# This API is not supported for the user.
RESOURCENOTFOUND_INVALIDUSER = 'ResourceNotFound.InvalidUser'

# The playback domain name does not exist.
RESOURCENOTFOUND_PLAYDOMAINNORECORD = 'ResourceNotFound.PlayDomainNoRecord'

# The push domain name does not exist.
RESOURCENOTFOUND_PUSHDOMAINNORECORD = 'ResourceNotFound.PushDomainNoRecord'

# The service has been suspended due to account arrears. Please top up it to a positive balance to activate the service first.
RESOURCENOTFOUND_STOPSERVICE = 'ResourceNotFound.StopService'

# The `TaskId` does not exist.
RESOURCENOTFOUND_TASKID = 'ResourceNotFound.TaskId'

# 
RESOURCENOTFOUND_USERDISABLESERVICE = 'ResourceNotFound.UserDisableService'

# The LVB service has not been activated.
RESOURCENOTFOUND_USERNOTEXIST = 'ResourceNotFound.UserNotExist'

# The user does not exist.
RESOURCENOTFOUND_USERNOTFOUNT = 'ResourceNotFound.UserNotFount'

# The watermark does not exist.
RESOURCENOTFOUND_WATERMARKNOTEXIST = 'ResourceNotFound.WatermarkNotExist'

# The resource is unavailable.
RESOURCEUNAVAILABLE = 'ResourceUnavailable'

# The VOD service has not been activated.
RESOURCEUNAVAILABLE_INVALIDVODSTATUS = 'ResourceUnavailable.InvalidVodStatus'

# The stream does not exist.
RESOURCEUNAVAILABLE_STREAMNOTEXIST = 'ResourceUnavailable.StreamNotExist'

# Unauthorized operation.
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'

# Unknown parameter.
UNKNOWNPARAMETER = 'UnknownParameter'

# Unsupported operation.
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# Not a LVB code/new console mode
UNSUPPORTEDOPERATION_NOTLVBCODEMODE = 'UnsupportedOperation.NotLVBCodeMode'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import json

from tencentcloud.common.exception.tencent_cloud_sdk_exception import TencentCloudSDKException
from tencentcloud.common.abstract_client import AbstractClient
from tencentcloud.ses.v20201002 import models


class SesClient(AbstractClient):
    _apiVersion = '2020-10-02'
    _endpoint = 'ses.tencentcloudapi.com'
    _service = 'ses'


    def BatchSendEmail(self, request):
        """This API is used to send a TEXT or HTML email to multiple recipients at a time for marketing or notification purposes. By default, you can send emails using a template only. To send custom content, please contact your sales rep to enable this feature. You need to create a recipient group with email addresses first and then send emails by group ID. SES supports scheduled and recurring email sending tasks. You need to pass in `TimedParam` for a scheduled task and `CycleParam` for a recurring one.

        :param request: Request instance for BatchSendEmail.
        :type request: :class:`tencentcloud.ses.v20201002.models.BatchSendEmailRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.BatchSendEmailResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("BatchSendEmail", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.BatchSendEmailResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateEmailAddress(self, request):
        """After the sender domain is verified, you need a sender address to send emails. For example, if your sender domain is mail.qcloud.com, your sender address can be service@mail.qcloud.com. If you want to display your name (such as "Tencent Cloud") in the inbox list of the recipients, the sender address should be in the format of `Tencent Cloud <email address>`. Please note that there must be a space between your name and the first angle bracket.

        :param request: Request instance for CreateEmailAddress.
        :type request: :class:`tencentcloud.ses.v20201002.models.CreateEmailAddressRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.CreateEmailAddressResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateEmailAddress", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateEmailAddressResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateEmailIdentity(self, request):
        """This API is used to create a sender domain. Before you can send an email using Tencent Cloud SES, you must create a sender domain as your identity. It can be the domain of your website or mobile app. You must verify the domain to prove that you own it and authorize Tencent Cloud SES to use it to send emails.

        :param request: Request instance for CreateEmailIdentity.
        :type request: :class:`tencentcloud.ses.v20201002.models.CreateEmailIdentityRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.CreateEmailIdentityResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateEmailIdentity", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateEmailIdentityResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateEmailTemplate(self, request):
        """This API is used to create a TEXT or HTML email template. To create an HTML template, ensure that it does not include external CSS files. You can use {{variable name}} to specify a variable in the template.
        Note: Only an approved template can be used to send emails.

        :param request: Request instance for CreateEmailTemplate.
        :type request: :class:`tencentcloud.ses.v20201002.models.CreateEmailTemplateRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.CreateEmailTemplateResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateEmailTemplate", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateEmailTemplateResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateReceiver(self, request):
        """This API is used to create a recipient group, which is the list of target email addresses for batch sending emails. After creating a group, you need to upload recipient email addresses. Then, you can create a sending task and select the group to batch send emails.

        :param request: Request instance for CreateReceiver.
        :type request: :class:`tencentcloud.ses.v20201002.models.CreateReceiverRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.CreateReceiverResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateReceiver", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateReceiverResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def CreateReceiverDetail(self, request):
        """This API is used to add recipient email addresses (up to 100,000 at a time) to a recipient group. This will be processed asynchronously. You can upload recipient email addresses only once. If the data volume is large, it may take some time to upload. You can check the recipient group to learn the upload status and upload quantity.

        :param request: Request instance for CreateReceiverDetail.
        :type request: :class:`tencentcloud.ses.v20201002.models.CreateReceiverDetailRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.CreateReceiverDetailResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("CreateReceiverDetail", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.CreateReceiverDetailResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DeleteBlackList(self, request):
        """This API is used to unblocklist email addresses. If you confirm that a blocklisted recipient address is valid and active, you can remove it from Tencent Cloud’s address blocklist database.

        :param request: Request instance for DeleteBlackList.
        :type request: :class:`tencentcloud.ses.v20201002.models.DeleteBlackListRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.DeleteBlackListResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteBlackList", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DeleteBlackListResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DeleteEmailAddress(self, request):
        """This API is used to delete a sender address.

        :param request: Request instance for DeleteEmailAddress.
        :type request: :class:`tencentcloud.ses.v20201002.models.DeleteEmailAddressRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.DeleteEmailAddressResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteEmailAddress", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DeleteEmailAddressResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DeleteEmailIdentity(self, request):
        """This API is used to delete a sender domain. After deleted, the sender domain can no longer be used to send emails.

        :param request: Request instance for DeleteEmailIdentity.
        :type request: :class:`tencentcloud.ses.v20201002.models.DeleteEmailIdentityRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.DeleteEmailIdentityResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteEmailIdentity", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DeleteEmailIdentityResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DeleteEmailTemplate(self, request):
        """This API is used to delete an email template.

        :param request: Request instance for DeleteEmailTemplate.
        :type request: :class:`tencentcloud.ses.v20201002.models.DeleteEmailTemplateRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.DeleteEmailTemplateResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteEmailTemplate", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DeleteEmailTemplateResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def DeleteReceiver(self, request):
        """This API is used to delete a recipient group and all recipient email addresses in the group based on the recipient group ID.

        :param request: Request instance for DeleteReceiver.
        :type request: :class:`tencentcloud.ses.v20201002.models.DeleteReceiverRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.DeleteReceiverResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("DeleteReceiver", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.DeleteReceiverResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def GetEmailIdentity(self, request):
        """This API is used to get the configuration details of a sender domain.

        :param request: Request instance for GetEmailIdentity.
        :type request: :class:`tencentcloud.ses.v20201002.models.GetEmailIdentityRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.GetEmailIdentityResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("GetEmailIdentity", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.GetEmailIdentityResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def GetEmailTemplate(self, request):
        """This API is used to get the details of a template.

        :param request: Request instance for GetEmailTemplate.
        :type request: :class:`tencentcloud.ses.v20201002.models.GetEmailTemplateRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.GetEmailTemplateResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("GetEmailTemplate", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.GetEmailTemplateResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def GetSendEmailStatus(self, request):
        """This API is used to get email sending status. Only data within 30 days can be queried.

        :param request: Request instance for GetSendEmailStatus.
        :type request: :class:`tencentcloud.ses.v20201002.models.GetSendEmailStatusRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.GetSendEmailStatusResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("GetSendEmailStatus", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.GetSendEmailStatusResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def GetStatisticsReport(self, request):
        """This API is used to get the email sending statistics over a recent period, including data on sent emails, delivery success rate, open rate, bounce rate, and so on.

        :param request: Request instance for GetStatisticsReport.
        :type request: :class:`tencentcloud.ses.v20201002.models.GetStatisticsReportRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.GetStatisticsReportResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("GetStatisticsReport", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.GetStatisticsReportResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ListBlackEmailAddress(self, request):
        """The API is used to get blocklisted addresses. In the case of a hard bounce, Tencent Cloud will blocklist the recipient address and do not allow any user to send emails to this address. If you confirm that this is a misjudgment, you can remove it from the blocklist.

        :param request: Request instance for ListBlackEmailAddress.
        :type request: :class:`tencentcloud.ses.v20201002.models.ListBlackEmailAddressRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.ListBlackEmailAddressResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ListBlackEmailAddress", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ListBlackEmailAddressResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ListEmailAddress(self, request):
        """This API is used to get the list of sender addresses.

        :param request: Request instance for ListEmailAddress.
        :type request: :class:`tencentcloud.ses.v20201002.models.ListEmailAddressRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.ListEmailAddressResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ListEmailAddress", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ListEmailAddressResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ListEmailIdentities(self, request):
        """This API is used to get the list of sender domains, including verified and unverified domains.

        :param request: Request instance for ListEmailIdentities.
        :type request: :class:`tencentcloud.ses.v20201002.models.ListEmailIdentitiesRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.ListEmailIdentitiesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ListEmailIdentities", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ListEmailIdentitiesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ListEmailTemplates(self, request):
        """This API is used to get the list of email templates.

        :param request: Request instance for ListEmailTemplates.
        :type request: :class:`tencentcloud.ses.v20201002.models.ListEmailTemplatesRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.ListEmailTemplatesResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ListEmailTemplates", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ListEmailTemplatesResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ListReceivers(self, request):
        """This API is used to query recipient groups. It supports pagination, fuzzy query, and query by status.

        :param request: Request instance for ListReceivers.
        :type request: :class:`tencentcloud.ses.v20201002.models.ListReceiversRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.ListReceiversResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ListReceivers", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ListReceiversResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def ListSendTasks(self, request):
        """This API is used to query batch email sending tasks (including immediate, scheduled, and recurring tasks) by page. You can query task data including the number of emails requested to be sent, the number of sent emails, the number of cached emails, and task status.

        :param request: Request instance for ListSendTasks.
        :type request: :class:`tencentcloud.ses.v20201002.models.ListSendTasksRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.ListSendTasksResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("ListSendTasks", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.ListSendTasksResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def SendEmail(self, request):
        """This API is used to send a TEXT or HTML email triggered for authentication or transaction. By default, you can send emails using a template only. To send custom content, please contact your sales rep to enable this feature.

        :param request: Request instance for SendEmail.
        :type request: :class:`tencentcloud.ses.v20201002.models.SendEmailRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.SendEmailResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("SendEmail", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.SendEmailResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def UpdateEmailIdentity(self, request):
        """This API is used to verify whether your DNS configuration is correct.

        :param request: Request instance for UpdateEmailIdentity.
        :type request: :class:`tencentcloud.ses.v20201002.models.UpdateEmailIdentityRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.UpdateEmailIdentityResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("UpdateEmailIdentity", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.UpdateEmailIdentityResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


    def UpdateEmailTemplate(self, request):
        """This API is used to update an email template. An updated template must be approved again before it can be used.

        :param request: Request instance for UpdateEmailTemplate.
        :type request: :class:`tencentcloud.ses.v20201002.models.UpdateEmailTemplateRequest`
        :rtype: :class:`tencentcloud.ses.v20201002.models.UpdateEmailTemplateResponse`

        """
        try:
            params = request._serialize()
            headers = request.headers
            body = self.call("UpdateEmailTemplate", params, headers=headers)
            response = json.loads(body)
            if "Error" not in response["Response"]:
                model = models.UpdateEmailTemplateResponse()
                model._deserialize(response["Response"])
                return model
            else:
                code = response["Response"]["Error"]["Code"]
                message = response["Response"]["Error"]["Message"]
                reqid = response["Response"]["RequestId"]
                raise TencentCloudSDKException(code, message, reqid)
        except Exception as e:
            if isinstance(e, TencentCloudSDKException):
                raise
            else:
                raise TencentCloudSDKException(e.message, e.message)


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class AccountVpcInfo(AbstractModel):
    """VPC information of a Private DNS account

    """

    def __init__(self):
        r"""
        :param UniqVpcId: VpcId: vpc-xadsafsdasd
        :type UniqVpcId: str
        :param Region: VPC region: ap-guangzhou, ap-shanghai
Note: this field may return `null`, indicating that no valid values can be obtained.
        :type Region: str
        :param Uin: VPC account: 123456789
Note: this field may return `null`, indicating that no valid values can be obtained.
        :type Uin: str
        :param VpcName: VPC name: testname
Note: this field may return `null`, indicating that no valid values can be obtained.
        :type VpcName: str
        """
        self.UniqVpcId = None
        self.Region = None
        self.Uin = None
        self.VpcName = None


    def _deserialize(self, params):
        self.UniqVpcId = params.get("UniqVpcId")
        self.Region = params.get("Region")
        self.Uin = params.get("Uin")
        self.VpcName = params.get("VpcName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class AccountVpcInfoOut(AbstractModel):
    """Output parameters of the associated VPC

    """

    def __init__(self):
        r"""
        :param VpcId: VpcId: vpc-xadsafsdasd
        :type VpcId: str
        :param Region: Region: ap-guangzhou, ap-shanghai
        :type Region: str
        :param Uin: VPC ID: 123456789
        :type Uin: str
        :param VpcName: VPC name: testname
        :type VpcName: str
        """
        self.VpcId = None
        self.Region = None
        self.Uin = None
        self.VpcName = None


    def _deserialize(self, params):
        self.VpcId = params.get("VpcId")
        self.Region = params.get("Region")
        self.Uin = params.get("Uin")
        self.VpcName = params.get("VpcName")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class AccountVpcInfoOutput(AbstractModel):
    """Output parameters of the associated VPC

    """

    def __init__(self):
        r"""
        :param Uin: UIN of the VPC account
        :type Uin: str
        :param UniqVpcId: VPC ID
        :type UniqVpcId: str
        :param Region: Region
        :type Region: str
        """
        self.Uin = None
        self.UniqVpcId = None
        self.Region = None


    def _deserialize(self, params):
        self.Uin = params.get("Uin")
        self.UniqVpcId = params.get("UniqVpcId")
        self.Region = params.get("Region")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class AuditLog(AbstractModel):
    """Operation log

    """

    def __init__(self):
        r"""
        :param Resource: Log type
        :type Resource: str
        :param Metric: Log table name
        :type Metric: str
        :param TotalCount: Total number of logs
        :type TotalCount: int
        :param DataSet: List of logs
        :type DataSet: list of AuditLogInfo
        """
        self.Resource = None
        self.Metric = None
        self.TotalCount = None
        self.DataSet = None


    def _deserialize(self, params):
        self.Resource = params.get("Resource")
        self.Metric = params.get("Metric")
        self.TotalCount = params.get("TotalCount")
        if params.get("DataSet") is not None:
            self.DataSet = []
            for item in params.get("DataSet"):
                obj = AuditLogInfo()
                obj._deserialize(item)
                self.DataSet.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class AuditLogInfo(AbstractModel):
    """Log details

    """

    def __init__(self):
        r"""
        :param Date: Time
        :type Date: str
        :param OperatorUin: Operator UIN
        :type OperatorUin: str
        :param Content: Log content
        :type Content: str
        """
        self.Date = None
        self.OperatorUin = None
        self.Content = None


    def _deserialize(self, params):
        self.Date = params.get("Date")
        self.OperatorUin = params.get("OperatorUin")
        self.Content = params.get("Content")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreatePrivateDNSAccountRequest(AbstractModel):
    """CreatePrivateDNSAccount request structure.

    """

    def __init__(self):
        r"""
        :param Account: Private DNS account
        :type Account: :class:`tencentcloud.privatedns.v20201028.models.PrivateDNSAccount`
        """
        self.Account = None


    def _deserialize(self, params):
        if params.get("Account") is not None:
            self.Account = PrivateDNSAccount()
            self.Account._deserialize(params.get("Account"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreatePrivateDNSAccountResponse(AbstractModel):
    """CreatePrivateDNSAccount response structure.

    """

    def __init__(self):
        r"""
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class CreatePrivateZoneRecordRequest(AbstractModel):
    """CreatePrivateZoneRecord request structure.

    """

    def __init__(self):
        r"""
        :param ZoneId: Private domain ID
        :type ZoneId: str
        :param RecordType: Record type. Valid values: "A", "AAAA", "CNAME", "MX", "TXT", "PTR"
        :type RecordType: str
        :param SubDomain: Subdomain, such as "www", "m", and "@"
        :type SubDomain: str
        :param RecordValue: Record value, such as IP: 192.168.10.2, CNAME: cname.qcloud.com., and MX: mail.qcloud.com.
        :type RecordValue: str
        :param Weight: Record weight. Value range: 1–100
        :type Weight: int
        :param MX: MX priority, which is required when the record type is MX. Valid values: 5, 10, 15, 20, 30, 40, 50
        :type MX: int
        :param TTL: Record cache time. The smaller the value, the faster the record will take effect. Value range: 1–86400s. Default value: 600
        :type TTL: int
        """
        self.ZoneId = None
        self.RecordType = None
        self.SubDomain = None
        self.RecordValue = None
        self.Weight = None
        self.MX = None
        self.TTL = None


    def _deserialize(self, params):
        self.ZoneId = params.get("ZoneId")
        self.RecordType = params.get("RecordType")
        self.SubDomain = params.get("SubDomain")
        self.RecordValue = params.get("RecordValue")
        self.Weight = params.get("Weight")
        self.MX = params.get("MX")
        self.TTL = params.get("TTL")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreatePrivateZoneRecordResponse(AbstractModel):
    """CreatePrivateZoneRecord response structure.

    """

    def __init__(self):
        r"""
        :param RecordId: Record ID
        :type RecordId: str
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.RecordId = None
        self.RequestId = None


    def _deserialize(self, params):
        self.RecordId = params.get("RecordId")
        self.RequestId = params.get("RequestId")


class CreatePrivateZoneRequest(AbstractModel):
    """CreatePrivateZone request structure.

    """

    def __init__(self):
        r"""
        :param Domain: Domain name, which must be in the format of standard TLD
        :type Domain: str
        :param TagSet: Tags the private domain when it is created
        :type TagSet: list of TagInfo
        :param VpcSet: Associates the private domain to a VPC when it is created
        :type VpcSet: list of VpcInfo
        :param Remark: Remarks
        :type Remark: str
        :param DnsForwardStatus: Whether to enable subdomain recursive DNS. Valid values: ENABLED, DISABLED. Default value: DISABLED
        :type DnsForwardStatus: str
        :param Vpcs: Associates the private domain to a VPC when it is created
        :type Vpcs: list of VpcInfo
        :param AccountVpcSet: List of authorized accounts' VPCs to associate with the private domain
        :type AccountVpcSet: list of AccountVpcInfo
        """
        self.Domain = None
        self.TagSet = None
        self.VpcSet = None
        self.Remark = None
        self.DnsForwardStatus = None
        self.Vpcs = None
        self.AccountVpcSet = None


    def _deserialize(self, params):
        self.Domain = params.get("Domain")
        if params.get("TagSet") is not None:
            self.TagSet = []
            for item in params.get("TagSet"):
                obj = TagInfo()
                obj._deserialize(item)
                self.TagSet.append(obj)
        if params.get("VpcSet") is not None:
            self.VpcSet = []
            for item in params.get("VpcSet"):
                obj = VpcInfo()
                obj._deserialize(item)
                self.VpcSet.append(obj)
        self.Remark = params.get("Remark")
        self.DnsForwardStatus = params.get("DnsForwardStatus")
        if params.get("Vpcs") is not None:
            self.Vpcs = []
            for item in params.get("Vpcs"):
                obj = VpcInfo()
                obj._deserialize(item)
                self.Vpcs.append(obj)
        if params.get("AccountVpcSet") is not None:
            self.AccountVpcSet = []
            for item in params.get("AccountVpcSet"):
                obj = AccountVpcInfo()
                obj._deserialize(item)
                self.AccountVpcSet.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class CreatePrivateZoneResponse(AbstractModel):
    """CreatePrivateZone response structure.

    """

    def __init__(self):
        r"""
        :param ZoneId: Private domain ID, such as zone-xxxxxx
        :type ZoneId: str
        :param Domain: Private domain
        :type Domain: str
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.ZoneId = None
        self.Domain = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ZoneId = params.get("ZoneId")
        self.Domain = params.get("Domain")
        self.RequestId = params.get("RequestId")


class DatePoint(AbstractModel):
    """Time statistics

    """

    def __init__(self):
        r"""
        :param Date: Time
        :type Date: str
        :param Value: Value
        :type Value: int
        """
        self.Date = None
        self.Value = None


    def _deserialize(self, params):
        self.Date = params.get("Date")
        self.Value = params.get("Value")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeAccountVpcListRequest(AbstractModel):
    """DescribeAccountVpcList request structure.

    """

    def __init__(self):
        r"""
        :param AccountUin: UIN of account
        :type AccountUin: str
        :param Offset: Pagination offset, starting from 0
        :type Offset: int
        :param Limit: Number of entries per page. Maximum value: `100`. Default value: `20`
        :type Limit: int
        :param Filters: Filter parameters
        :type Filters: list of Filter
        """
        self.AccountUin = None
        self.Offset = None
        self.Limit = None
        self.Filters = None


    def _deserialize(self, params):
        self.AccountUin = params.get("AccountUin")
        self.Offset = params.get("Offset")
        self.Limit = params.get("Limit")
        if params.get("Filters") is not None:
            self.Filters = []
            for item in params.get("Filters"):
                obj = Filter()
                obj._deserialize(item)
                self.Filters.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeAccountVpcListResponse(AbstractModel):
    """DescribeAccountVpcList response structure.

    """

    def __init__(self):
        r"""
        :param TotalCount: Number of VPCs
        :type TotalCount: int
        :param VpcSet: VPC list
        :type VpcSet: list of AccountVpcInfoOut
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.TotalCount = None
        self.VpcSet = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalCount = params.get("TotalCount")
        if params.get("VpcSet") is not None:
            self.VpcSet = []
            for item in params.get("VpcSet"):
                obj = AccountVpcInfoOut()
                obj._deserialize(item)
                self.VpcSet.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeAuditLogRequest(AbstractModel):
    """DescribeAuditLog request structure.

    """

    def __init__(self):
        r"""
        :param TimeRangeBegin: Request volume statistics start time
        :type TimeRangeBegin: str
        :param Filters: Filter parameter. Valid values: ZoneId (private domain ID), Domain (private domain), OperatorUin (operator account ID)
        :type Filters: list of Filter
        :param TimeRangeEnd: Request volume statistics end time
        :type TimeRangeEnd: str
        :param Offset: Pagination offset, starting from 0
        :type Offset: int
        :param Limit: Number of entries per page. Maximum value: 100. Default value: 20
        :type Limit: int
        """
        self.TimeRangeBegin = None
        self.Filters = None
        self.TimeRangeEnd = None
        self.Offset = None
        self.Limit = None


    def _deserialize(self, params):
        self.TimeRangeBegin = params.get("TimeRangeBegin")
        if params.get("Filters") is not None:
            self.Filters = []
            for item in params.get("Filters"):
                obj = Filter()
                obj._deserialize(item)
                self.Filters.append(obj)
        self.TimeRangeEnd = params.get("TimeRangeEnd")
        self.Offset = params.get("Offset")
        self.Limit = params.get("Limit")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeAuditLogResponse(AbstractModel):
    """DescribeAuditLog response structure.

    """

    def __init__(self):
        r"""
        :param Data: List of operation logs
        :type Data: list of AuditLog
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.Data = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = []
            for item in params.get("Data"):
                obj = AuditLog()
                obj._deserialize(item)
                self.Data.append(obj)
        self.RequestId = params.get("RequestId")


class DescribeDashboardRequest(AbstractModel):
    """DescribeDashboard request structure.

    """


class DescribeDashboardResponse(AbstractModel):
    """DescribeDashboard response structure.

    """

    def __init__(self):
        r"""
        :param ZoneTotal: Total number of private domain DNS records
        :type ZoneTotal: int
        :param ZoneVpcCount: Number of VPCs associated with private domain
        :type ZoneVpcCount: int
        :param RequestTotalCount: Total number of historical requests
        :type RequestTotalCount: int
        :param FlowUsage: Traffic package usage
        :type FlowUsage: list of FlowUsage
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.ZoneTotal = None
        self.ZoneVpcCount = None
        self.RequestTotalCount = None
        self.FlowUsage = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ZoneTotal = params.get("ZoneTotal")
        self.ZoneVpcCount = params.get("ZoneVpcCount")
        self.RequestTotalCount = params.get("RequestTotalCount")
        if params.get("FlowUsage") is not None:
            self.FlowUsage = []
            for item in params.get("FlowUsage"):
                obj = FlowUsage()
                obj._deserialize(item)
                self.FlowUsage.append(obj)
        self.RequestId = params.get("RequestId")


class DescribePrivateDNSAccountListRequest(AbstractModel):
    """DescribePrivateDNSAccountList request structure.

    """

    def __init__(self):
        r"""
        :param Offset: Pagination offset, starting from `0`
        :type Offset: int
        :param Limit: Number of entries per page. Maximum value: `100`. Default value: `20`
        :type Limit: int
        :param Filters: Filter parameters
        :type Filters: list of Filter
        """
        self.Offset = None
        self.Limit = None
        self.Filters = None


    def _deserialize(self, params):
        self.Offset = params.get("Offset")
        self.Limit = params.get("Limit")
        if params.get("Filters") is not None:
            self.Filters = []
            for item in params.get("Filters"):
                obj = Filter()
                obj._deserialize(item)
                self.Filters.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribePrivateDNSAccountListResponse(AbstractModel):
    """DescribePrivateDNSAccountList response structure.

    """

    def __init__(self):
        r"""
        :param TotalCount: Number of Private DNS accounts
        :type TotalCount: int
        :param AccountSet: List of Private DNS accounts
        :type AccountSet: list of PrivateDNSAccount
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.TotalCount = None
        self.AccountSet = None
        self.RequestId = None


    def _deserialize(self, params):
        self.TotalCount = params.get("TotalCount")
        if params.get("AccountSet") is not None:
            self.AccountSet = []
            for item in params.get("AccountSet"):
                obj = PrivateDNSAccount()
                obj._deserialize(item)
                self.AccountSet.append(obj)
        self.RequestId = params.get("RequestId")


class DescribePrivateZoneServiceRequest(AbstractModel):
    """DescribePrivateZoneService request structure.

    """


class DescribePrivateZoneServiceResponse(AbstractModel):
    """DescribePrivateZoneService response structure.

    """

    def __init__(self):
        r"""
        :param ServiceStatus: Private DNS service activation status. Valid values: ENABLED, DISABLED
        :type ServiceStatus: str
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.ServiceStatus = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ServiceStatus = params.get("ServiceStatus")
        self.RequestId = params.get("RequestId")


class DescribeQuotaUsageRequest(AbstractModel):
    """DescribeQuotaUsage request structure.

    """


class DescribeQuotaUsageResponse(AbstractModel):
    """DescribeQuotaUsage response structure.

    """

    def __init__(self):
        r"""
        :param TldQuota: TLD quota usage
        :type TldQuota: :class:`tencentcloud.privatedns.v20201028.models.TldQuota`
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.TldQuota = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("TldQuota") is not None:
            self.TldQuota = TldQuota()
            self.TldQuota._deserialize(params.get("TldQuota"))
        self.RequestId = params.get("RequestId")


class DescribeRequestDataRequest(AbstractModel):
    """DescribeRequestData request structure.

    """

    def __init__(self):
        r"""
        :param TimeRangeBegin: Request volume statistics start time in the format of 2020-11-22 00:00:00
        :type TimeRangeBegin: str
        :param Filters: Filter parameter:
        :type Filters: list of Filter
        :param TimeRangeEnd: Request volume statistics end time in the format of 2020-11-22 23:59:59
        :type TimeRangeEnd: str
        """
        self.TimeRangeBegin = None
        self.Filters = None
        self.TimeRangeEnd = None


    def _deserialize(self, params):
        self.TimeRangeBegin = params.get("TimeRangeBegin")
        if params.get("Filters") is not None:
            self.Filters = []
            for item in params.get("Filters"):
                obj = Filter()
                obj._deserialize(item)
                self.Filters.append(obj)
        self.TimeRangeEnd = params.get("TimeRangeEnd")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class DescribeRequestDataResponse(AbstractModel):
    """DescribeRequestData response structure.

    """

    def __init__(self):
        r"""
        :param Data: Request volume statistics table
        :type Data: list of MetricData
        :param Interval: Request volume unit time. Valid values: Day, Hour
        :type Interval: str
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.Data = None
        self.Interval = None
        self.RequestId = None


    def _deserialize(self, params):
        if params.get("Data") is not None:
            self.Data = []
            for item in params.get("Data"):
                obj = MetricData()
                obj._deserialize(item)
                self.Data.append(obj)
        self.Interval = params.get("Interval")
        self.RequestId = params.get("RequestId")


class Filter(AbstractModel):
    """Filter parameter

    """

    def __init__(self):
        r"""
        :param Name: Parameter name
        :type Name: str
        :param Values: Array of parameter values
        :type Values: list of str
        """
        self.Name = None
        self.Values = None


    def _deserialize(self, params):
        self.Name = params.get("Name")
        self.Values = params.get("Values")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class FlowUsage(AbstractModel):
    """Traffic package usage

    """

    def __init__(self):
        r"""
        :param FlowType: Traffic package type, Valid values: ZONE (private domain); TRAFFIC (DNS traffic package)
        :type FlowType: str
        :param TotalQuantity: Traffic package quota
        :type TotalQuantity: int
        :param AvailableQuantity: Available quota of traffic package
        :type AvailableQuantity: int
        """
        self.FlowType = None
        self.TotalQuantity = None
        self.AvailableQuantity = None


    def _deserialize(self, params):
        self.FlowType = params.get("FlowType")
        self.TotalQuantity = params.get("TotalQuantity")
        self.AvailableQuantity = params.get("AvailableQuantity")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class MetricData(AbstractModel):
    """Statistics table

    """

    def __init__(self):
        r"""
        :param Resource: Resource description
        :type Resource: str
        :param Metric: Table name
        :type Metric: str
        :param DataSet: Table data
        :type DataSet: list of DatePoint
        """
        self.Resource = None
        self.Metric = None
        self.DataSet = None


    def _deserialize(self, params):
        self.Resource = params.get("Resource")
        self.Metric = params.get("Metric")
        if params.get("DataSet") is not None:
            self.DataSet = []
            for item in params.get("DataSet"):
                obj = DatePoint()
                obj._deserialize(item)
                self.DataSet.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ModifyPrivateZoneRecordRequest(AbstractModel):
    """ModifyPrivateZoneRecord request structure.

    """

    def __init__(self):
        r"""
        :param ZoneId: Private domain ID
        :type ZoneId: str
        :param RecordId: Record ID
        :type RecordId: str
        :param RecordType: Record type. Valid values: "A", "AAAA", "CNAME", "MX", "TXT", "PTR"
        :type RecordType: str
        :param SubDomain: Subdomain, such as "www", "m", and "@"
        :type SubDomain: str
        :param RecordValue: Record value, such as IP: 192.168.10.2, CNAME: cname.qcloud.com., and MX: mail.qcloud.com.
        :type RecordValue: str
        :param Weight: Record weight. Value range: 1–100
        :type Weight: int
        :param MX: MX priority, which is required when the record type is MX. Valid values: 5, 10, 15, 20, 30, 40, 50
        :type MX: int
        :param TTL: Record cache time. The smaller the value, the faster the record will take effect. Value range: 1–86400s. Default value: 600
        :type TTL: int
        """
        self.ZoneId = None
        self.RecordId = None
        self.RecordType = None
        self.SubDomain = None
        self.RecordValue = None
        self.Weight = None
        self.MX = None
        self.TTL = None


    def _deserialize(self, params):
        self.ZoneId = params.get("ZoneId")
        self.RecordId = params.get("RecordId")
        self.RecordType = params.get("RecordType")
        self.SubDomain = params.get("SubDomain")
        self.RecordValue = params.get("RecordValue")
        self.Weight = params.get("Weight")
        self.MX = params.get("MX")
        self.TTL = params.get("TTL")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ModifyPrivateZoneRecordResponse(AbstractModel):
    """ModifyPrivateZoneRecord response structure.

    """

    def __init__(self):
        r"""
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class ModifyPrivateZoneRequest(AbstractModel):
    """ModifyPrivateZone request structure.

    """

    def __init__(self):
        r"""
        :param ZoneId: Private domain ID
        :type ZoneId: str
        :param Remark: Remarks
        :type Remark: str
        :param DnsForwardStatus: Whether to enable subdomain recursive DNS. Valid values: ENABLED, DISABLED
        :type DnsForwardStatus: str
        """
        self.ZoneId = None
        self.Remark = None
        self.DnsForwardStatus = None


    def _deserialize(self, params):
        self.ZoneId = params.get("ZoneId")
        self.Remark = params.get("Remark")
        self.DnsForwardStatus = params.get("DnsForwardStatus")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ModifyPrivateZoneResponse(AbstractModel):
    """ModifyPrivateZone response structure.

    """

    def __init__(self):
        r"""
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.RequestId = None


    def _deserialize(self, params):
        self.RequestId = params.get("RequestId")


class ModifyPrivateZoneVpcRequest(AbstractModel):
    """ModifyPrivateZoneVpc request structure.

    """

    def __init__(self):
        r"""
        :param ZoneId: Private domain ID
        :type ZoneId: str
        :param VpcSet: List of all VPCs associated with private domain
        :type VpcSet: list of VpcInfo
        :param AccountVpcSet: List of authorized accounts' VPCs to associate with the private domain
        :type AccountVpcSet: list of AccountVpcInfo
        """
        self.ZoneId = None
        self.VpcSet = None
        self.AccountVpcSet = None


    def _deserialize(self, params):
        self.ZoneId = params.get("ZoneId")
        if params.get("VpcSet") is not None:
            self.VpcSet = []
            for item in params.get("VpcSet"):
                obj = VpcInfo()
                obj._deserialize(item)
                self.VpcSet.append(obj)
        if params.get("AccountVpcSet") is not None:
            self.AccountVpcSet = []
            for item in params.get("AccountVpcSet"):
                obj = AccountVpcInfo()
                obj._deserialize(item)
                self.AccountVpcSet.append(obj)
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class ModifyPrivateZoneVpcResponse(AbstractModel):
    """ModifyPrivateZoneVpc response structure.

    """

    def __init__(self):
        r"""
        :param ZoneId: Private domain ID, such as zone-xxxxxx
        :type ZoneId: str
        :param VpcSet: List of VPCs associated with domain
        :type VpcSet: list of VpcInfo
        :param AccountVpcSet: List of authorized accounts' VPCs associated with the private domain
        :type AccountVpcSet: list of AccountVpcInfoOutput
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.ZoneId = None
        self.VpcSet = None
        self.AccountVpcSet = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ZoneId = params.get("ZoneId")
        if params.get("VpcSet") is not None:
            self.VpcSet = []
            for item in params.get("VpcSet"):
                obj = VpcInfo()
                obj._deserialize(item)
                self.VpcSet.append(obj)
        if params.get("AccountVpcSet") is not None:
            self.AccountVpcSet = []
            for item in params.get("AccountVpcSet"):
                obj = AccountVpcInfoOutput()
                obj._deserialize(item)
                self.AccountVpcSet.append(obj)
        self.RequestId = params.get("RequestId")


class PrivateDNSAccount(AbstractModel):
    """Private DNS account

    """

    def __init__(self):
        r"""
        :param Uin: Root account UIN
        :type Uin: str
        :param Account: Root account name
        :type Account: str
        :param Nickname: Account name
        :type Nickname: str
        """
        self.Uin = None
        self.Account = None
        self.Nickname = None


    def _deserialize(self, params):
        self.Uin = params.get("Uin")
        self.Account = params.get("Account")
        self.Nickname = params.get("Nickname")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class SubscribePrivateZoneServiceRequest(AbstractModel):
    """SubscribePrivateZoneService request structure.

    """


class SubscribePrivateZoneServiceResponse(AbstractModel):
    """SubscribePrivateZoneService response structure.

    """

    def __init__(self):
        r"""
        :param ServiceStatus: Private DNS service activation status
        :type ServiceStatus: str
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.ServiceStatus = None
        self.RequestId = None


    def _deserialize(self, params):
        self.ServiceStatus = params.get("ServiceStatus")
        self.RequestId = params.get("RequestId")


class TagInfo(AbstractModel):
    """Tag

    """

    def __init__(self):
        r"""
        :param TagKey: Tag key
        :type TagKey: str
        :param TagValue: Tag value
        :type TagValue: str
        """
        self.TagKey = None
        self.TagValue = None


    def _deserialize(self, params):
        self.TagKey = params.get("TagKey")
        self.TagValue = params.get("TagValue")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class TldQuota(AbstractModel):
    """TLD quota

    """

    def __init__(self):
        r"""
        :param Total: Total quota
        :type Total: int
        :param Used: Used quota
        :type Used: int
        :param Stock: Available quota
        :type Stock: int
        :param Quota: User’s quota
        :type Quota: int
        """
        self.Total = None
        self.Used = None
        self.Stock = None
        self.Quota = None


    def _deserialize(self, params):
        self.Total = params.get("Total")
        self.Used = params.get("Used")
        self.Stock = params.get("Stock")
        self.Quota = params.get("Quota")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class VpcInfo(AbstractModel):
    """VPC information

    """

    def __init__(self):
        r"""
        :param UniqVpcId: VpcId: vpc-xadsafsdasd
        :type UniqVpcId: str
        :param Region: VPC region: ap-guangzhou, ap-shanghai
        :type Region: str
        """
        self.UniqVpcId = None
        self.Region = None


    def _deserialize(self, params):
        self.UniqVpcId = params.get("UniqVpcId")
        self.Region = params.get("Region")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import warnings

from tencentcloud.common.abstract_model import AbstractModel


class DetailResults(AbstractModel):
    """Details of results returned by text moderation

    """

    def __init__(self):
        r"""
        :param Label: Result of the moderation. <br>`Normal`: normal content; `Porn`: pornographic content; `Abuse`: abusive content; **Ad**: advertising content; `Custom`: custom violating content
        :type Label: str
        :param Suggestion: Recommended follow-up action. <br>`Block`: block it automatically; `Review`: review the content again in human; **Pass**: pass
Note: This field may return `null`, indicating that no valid value can be found.
        :type Suggestion: str
        :param Keywords: This field returns the matched keywords. This parameter can include multiple returned values, which means multiple keywords are matched. If no keyword is returned but there is a `Score`, it means that the result of `Label` is determined by a semantic model.
Note: This field may return `null`, indicating that no valid value can be found.
        :type Keywords: list of str
        :param Score: This field indicates the convincing level of the `Label`, ranging from `0` (lowest) to `100` (highest). 
Note: This field may return `null`, indicating that no valid value can be found.
        :type Score: int
        :param LibType: It indicates the library type corresponding with the keyword. Valid values: `1` (blocklist/allowlist library) and `2` (custom keyword library). If no custom keyword library is configured, the default value is 1.
Note: This field may return `null`, indicating that no valid value can be found.
        :type LibType: int
        :param LibId: This field is **only valid when `Label` is `Custom`. It returns the custom library ID to facilitate the library management and configuration.
Note: This field may return `null`, indicating that no valid value can be found.
        :type LibId: str
        :param LibName: This field is **only valid when `Label` is `Custom` (custom keyword)`. It returns the custom library name to facilitate the library management and configuration.
Note: This field may return `null`, indicating that no valid value can be found.
        :type LibName: str
        :param SubLabel: The field returns the second-level labels under the current label.
Note: This field may return `null`, indicating that no valid value can be found.
        :type SubLabel: str
        """
        self.Label = None
        self.Suggestion = None
        self.Keywords = None
        self.Score = None
        self.LibType = None
        self.LibId = None
        self.LibName = None
        self.SubLabel = None


    def _deserialize(self, params):
        self.Label = params.get("Label")
        self.Suggestion = params.get("Suggestion")
        self.Keywords = params.get("Keywords")
        self.Score = params.get("Score")
        self.LibType = params.get("LibType")
        self.LibId = params.get("LibId")
        self.LibName = params.get("LibName")
        self.SubLabel = params.get("SubLabel")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class Device(AbstractModel):
    """This field indicates the device information of the service subscriber

    """

    def __init__(self):
        r"""
        :param IP: This field indicates the IP address of the device used by the service subscriber. <br>
Note: Currently, only IPv4 addresses can be recorded.
        :type IP: str
        :param Mac: This field indicates the MAC address used by the service subscriber to facilitate device identification and management. Its format and value are consistent with those of the standard MAC address.
        :type Mac: str
        :param TokenId: * In beta test. Available soon.*
        :type TokenId: str
        :param DeviceId: * In beta test. Available soon.*
        :type DeviceId: str
        :param IMEI: This field represents the **IMEI** (International Mobile Equipment Identity) number of the device used by the service subscriber. IMEI can be used to identify each independent mobile communication device, such as a mobile phone, which is convenient for device identification and management. <br>Note: IMEI is formatted with **15 to 17 numbers only**.
        :type IMEI: str
        :param IDFA: **Dedicated for iOS device**. This field indicates the **IDFA** (Identifier for Advertising) corresponding to the service subscriber. IDFA, a string of hexadecimal 32 characters including numbers and letters, is provided by Apple Inc. to identify the user.<br>
Note: Since the iOS14 update in 2021, Apple Inc. has allowed users to manually activate or deactivate IDFA, so the validity of the string identifier may be reduced.
        :type IDFA: str
        :param IDFV: **Dedicated for iOS device**. This field indicates the **IDFV** (Identifier for Vendor) corresponding to the service subscriber. IDFV, a string of hexadecimal 32 characters including numbers and letters, is provided by Apple Inc. to identify the vendor. IDFV can also be used as a unique device identifier.
        :type IDFV: str
        """
        self.IP = None
        self.Mac = None
        self.TokenId = None
        self.DeviceId = None
        self.IMEI = None
        self.IDFA = None
        self.IDFV = None


    def _deserialize(self, params):
        self.IP = params.get("IP")
        self.Mac = params.get("Mac")
        self.TokenId = params.get("TokenId")
        self.DeviceId = params.get("DeviceId")
        self.IMEI = params.get("IMEI")
        self.IDFA = params.get("IDFA")
        self.IDFV = params.get("IDFV")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class RiskDetails(AbstractModel):
    """Account risk detection results

    """

    def __init__(self):
        r"""
        :param Label: This field returns the risk categories after account information detection. Valid values: **RiskAccount** (the account is at risk), **RiskIP** (the IP address is at risk), and **RiskIMEI** (the mobile device identifier is at risk).
        :type Label: str
        :param Level: This field returns the risk levels after account information detection. Valid values: **1** (suspected to be at risk) and **2** (malicious risk).
        :type Level: int
        """
        self.Label = None
        self.Level = None


    def _deserialize(self, params):
        self.Label = params.get("Label")
        self.Level = params.get("Level")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class TextModerationRequest(AbstractModel):
    """TextModeration request structure.

    """

    def __init__(self):
        r"""
        :param Content: This field indicates the text content of the object to be moderated. The text needs to be encoded in utf-8 format and encrypted with Base64. It can contain up to 10,000 characters, calculated by unicode encoding.
        :type Content: str
        :param BizType: This field indicates the specific policy number, which is used for the API call and can be configured in the CMS console. If it's not entered (left empty), the default moderation policy is adopted. If it's entered, the moderation policies are specified for business scenarios. <br>Note: Biztype contains 3 to 32 characters, including numbers, letters and underscores only. Different Biztypes are associated with different business scenarios and moderation policies. Ensure that you use the Biztype corresponding to the policy you want to apply.
        :type BizType: str
        :param DataId: This field indicates the data ID you assigned to the object to be moderated, which is convenient for you to identify and manage the file. <br>Value: this field can contain **up to 64 characters**, including uppercase and lowercase letters, numbers and four special symbols (_, -, @, #)
        :type DataId: str
        :param User: This field indicates the user information related with the object to be moderated, which can be used to identify violating users at risk.
        :type User: :class:`tencentcloud.tms.v20201229.models.User`
        :param Device: This field indicates the device information related with the object to be moderated, which can be used to identify violating devices at risk.
        :type Device: :class:`tencentcloud.tms.v20201229.models.Device`
        """
        self.Content = None
        self.BizType = None
        self.DataId = None
        self.User = None
        self.Device = None


    def _deserialize(self, params):
        self.Content = params.get("Content")
        self.BizType = params.get("BizType")
        self.DataId = params.get("DataId")
        if params.get("User") is not None:
            self.User = User()
            self.User._deserialize(params.get("User"))
        if params.get("Device") is not None:
            self.Device = Device()
            self.Device._deserialize(params.get("Device"))
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


class TextModerationResponse(AbstractModel):
    """TextModeration response structure.

    """

    def __init__(self):
        r"""
        :param BizType: This field returns the BizType of the request parameters
        :type BizType: str
        :param Label: This field returns the **negative label with the highest priority** in the moderation results (DetailResults), which indicates the moderation result recommended by the model. It is recommended that you handle different violations with the suggested values according to your business needs. <br>Returned values: **Normal**: normal content; **Porn**: pornographic content; **Abuse**: abusive content; **Ad**: advertising content; **Custom**: custom violating content, and others such as objectionable, insecure or inappropriate content.
        :type Label: str
        :param Suggestion: This field returns the follow-up moderation suggestions. The returned value indicates the recommended operation after obtaining the moderation result. It is recommended that you handle different violations with the suggested values according to your business needs. <br>Returned values: **Block**: block; **Review**: human moderation; **Pass**: pass
        :type Suggestion: str
        :param Keywords: This field returns the keywords matched with the libraries in the moderated text under the current label to mark the specific violations (for example, *Friend me*). This parameter may have multiple returned values, indicating multiple keywords are matched. If the returned value is empty and the `Score` is not empty, it means that the negative label corresponding to the moderation result is a value returned from the semantic model judgment
Note: This field may return `null`, indicating that no valid value can be found.
        :type Keywords: list of str
        :param Score: This field returns the confidence level under the current label. Value range: 0 (**the lowest confidence level**) - 100 (**the highest confidence level**). The higher the value, the more likely the text is to belong to the category indicated by the current label. For example, *pornographic 99* indicates that the text is very likely to be pornographic, and *pornographic 0* indicates that the text is not pornographic
        :type Score: int
        :param DetailResults: This field returns the moderation results based on the text libraries. For details, see `DetailResults` in the data structure
Note: This field may return `null`, indicating that no valid value can be found.
        :type DetailResults: list of DetailResults
        :param RiskDetails: This field returns the detection results of violating accounts at risk, mainly including violation categories and risk levels. For details, see `RiskDetails` in the data structure
Note: This field may return `null`, indicating that no valid value can be found.
        :type RiskDetails: list of RiskDetails
        :param Extra: This field returns the extra information configured according to your needs. If it's not configured, the returned value is empty by default. <br>Note: the returned information varies based on different customers or Biztypes. If you need to configure this field, please submit a ticket or contact after-sales manager
Note: This field may return `null`, indicating that no valid value can be found.
        :type Extra: str
        :param DataId: This field returns the `DataId` in the request parameter corresponding to the moderated object
Note: This field may return `null`, indicating that no valid value can be found.
        :type DataId: str
        :param SubLabel: The field returns the second-level labels under the current label.
Note: This field may return `null`, indicating that no valid value can be found.
        :type SubLabel: str
        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
        :type RequestId: str
        """
        self.BizType = None
        self.Label = None
        self.Suggestion = None
        self.Keywords = None
        self.Score = None
        self.DetailResults = None
        self.RiskDetails = None
        self.Extra = None
        self.DataId = None
        self.SubLabel = None
        self.RequestId = None


    def _deserialize(self, params):
        self.BizType = params.get("BizType")
        self.Label = params.get("Label")
        self.Suggestion = params.get("Suggestion")
        self.Keywords = params.get("Keywords")
        self.Score = params.get("Score")
        if params.get("DetailResults") is not None:
            self.DetailResults = []
            for item in params.get("DetailResults"):
                obj = DetailResults()
                obj._deserialize(item)
                self.DetailResults.append(obj)
        if params.get("RiskDetails") is not None:
            self.RiskDetails = []
            for item in params.get("RiskDetails"):
                obj = RiskDetails()
                obj._deserialize(item)
                self.RiskDetails.append(obj)
        self.Extra = params.get("Extra")
        self.DataId = params.get("DataId")
        self.SubLabel = params.get("SubLabel")
        self.RequestId = params.get("RequestId")


class User(AbstractModel):
    """This field indicates the account-related information of the service subscriber

    """

    def __init__(self):
        r"""
        :param UserId: This field indicates the service subscriber ID. This ID can be used to optimize the moderation result judgment based on the account's violation records, which is helpful for auxiliary judgment when there is a risk of suspected violations.
        :type UserId: str
        :param Nickname: This field indicates the account nickname information of the service subscriber.
        :type Nickname: str
        :param AccountType: This field indicates the account type corresponding to the service subscriber ID.<br>
Use this field and the account ID (UserId) together to determine a unique account.
        :type AccountType: int
        :param Gender: This field indicates the gender information of the service subscriber's account.<br>
Values: **0** (default value, indicating the gender is unknown), **1** (male) and **2** (female).
        :type Gender: int
        :param Age: This field indicates the age information of the service subscriber's account.<br>
Values: Integers between **0** (default value, indicating that the age is unknown) and the number of (**custom maximum age**).
        :type Age: int
        :param Level: This field indicates the level information of the service subscriber's account.<br>
Values: **0** (default value, indicating that the level is unknown), **1** (lower level), **2** (medium level) and **3** (higher level). Currently, **custom levels are not supported**.
        :type Level: int
        :param Phone: This field indicates the mobile phone number information of the service subscriber's account. The mobile phone numbers in various regions of the world can be recorded.<br>
Note: Please keep the format of mobile phone number uniform. For example, uniformly use the area code format (086/+86), etc.
        :type Phone: str
        :param HeadUrl: This field indicates the URL of the service subscriber's profile photos formatted with .png, .jpg, .jpeg, .bmp, .gif and .webp.
Note: Up to 5 MB is supported, and the minimum resolution is 256 x 256. When it takes more than 3 seconds to download, the "download timeout" is returned.
        :type HeadUrl: str
        :param Desc: This field indicates the profile information of service subscribers. It can contain up to 5,000 characters, including Chinese characters, letters and special symbols.
        :type Desc: str
        """
        self.UserId = None
        self.Nickname = None
        self.AccountType = None
        self.Gender = None
        self.Age = None
        self.Level = None
        self.Phone = None
        self.HeadUrl = None
        self.Desc = None


    def _deserialize(self, params):
        self.UserId = params.get("UserId")
        self.Nickname = params.get("Nickname")
        self.AccountType = params.get("AccountType")
        self.Gender = params.get("Gender")
        self.Age = params.get("Age")
        self.Level = params.get("Level")
        self.Phone = params.get("Phone")
        self.HeadUrl = params.get("HeadUrl")
        self.Desc = params.get("Desc")
        memeber_set = set(params.keys())
        for name, value in vars(self).items():
            if name in memeber_set:
                memeber_set.remove(name)
        if len(memeber_set) > 0:
            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
        


# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# You do not have permission to perform this operation.
FAILEDOPERATION_AUTHERROR = 'FailedOperation.AuthError'

# Failed to cancel the order.
FAILEDOPERATION_CANCELORDERFAILED = 'FailedOperation.CancelOrderFailed'

# Failed to delete the certificate because it has been issued.
FAILEDOPERATION_CANNOTBEDELETEDISSUED = 'FailedOperation.CannotBeDeletedIssued'

# Free certificates cannot be deleted within 1 hour after being applied for.
FAILEDOPERATION_CANNOTBEDELETEDWITHINHOUR = 'FailedOperation.CannotBeDeletedWithinHour'

# Failed to get order information. Try again later.
FAILEDOPERATION_CANNOTGETORDER = 'FailedOperation.CannotGetOrder'

# The certificate already exists.
FAILEDOPERATION_CERTIFICATEEXISTS = 'FailedOperation.CertificateExists'

# The certificate is invalid.
FAILEDOPERATION_CERTIFICATEINVALID = 'FailedOperation.CertificateInvalid'

# The certificate and the private key do not match.
FAILEDOPERATION_CERTIFICATEMISMATCH = 'FailedOperation.CertificateMismatch'

# The certificate does not exist.
FAILEDOPERATION_CERTIFICATENOTFOUND = 'FailedOperation.CertificateNotFound'

# The number of free certificates exceeds the maximum value.
FAILEDOPERATION_EXCEEDSFREELIMIT = 'FailedOperation.ExceedsFreeLimit'

# The certificate status is incorrect.
FAILEDOPERATION_INVALIDCERTIFICATESTATUSCODE = 'FailedOperation.InvalidCertificateStatusCode'

# Incorrect parameters.
FAILEDOPERATION_INVALIDPARAM = 'FailedOperation.InvalidParam'

# The CA system is busy. Try again later.
FAILEDOPERATION_NETWORKERROR = 'FailedOperation.NetworkError'

# You do not have the permission to operate on this project.
FAILEDOPERATION_NOPROJECTPERMISSION = 'FailedOperation.NoProjectPermission'

# You have not completed the identity verification.
FAILEDOPERATION_NOREALNAMEAUTH = 'FailedOperation.NoRealNameAuth'

# This order has already been replaced.
FAILEDOPERATION_ORDERALREADYREPLACED = 'FailedOperation.OrderAlreadyReplaced'

# Failed to reissue a certificate.
FAILEDOPERATION_ORDERREPLACEFAILED = 'FailedOperation.OrderReplaceFailed'

# Internal error.
INTERNALERROR = 'InternalError'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# Error with CAM signature/authentication.
AUTHFAILURE = 'AuthFailure'

# Token verification failed.
AUTHFAILURE_TOKENFAILURE = 'AuthFailure.TokenFailure'

# `DryRun` Operation. It means that the request would have succeeded, but the `DryRun` parameter was used.
DRYRUNOPERATION = 'DryRunOperation'

# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# Failed to associate the private domain with the VPC.
FAILEDOPERATION_BINDZONEVPCFAILED = 'FailedOperation.BindZoneVpcFailed'

# Failed to create the record.
FAILEDOPERATION_CREATERECORDFAILED = 'FailedOperation.CreateRecordFailed'

# Failed to create the private domain.
FAILEDOPERATION_CREATEZONEFAILED = 'FailedOperation.CreateZoneFailed'

# Failed to modify the record.
FAILEDOPERATION_MODIFYRECORDFAILED = 'FailedOperation.ModifyRecordFailed'

# Failed to modify the private domain.
FAILEDOPERATION_MODIFYZONEFAILED = 'FailedOperation.ModifyZoneFailed'

# Internal error.
INTERNALERROR = 'InternalError'

# Undefined error.
INTERNALERROR_UNDEFIENDERROR = 'InternalError.UndefiendError'

# Incorrect parameter.
INVALIDPARAMETER = 'InvalidParameter'

# A bound account already exists.
INVALIDPARAMETER_ACCOUNTEXIST = 'InvalidParameter.AccountExist'

# Invalid CIDR.
INVALIDPARAMETER_ILLEGALCIDR = 'InvalidParameter.IllegalCidr'

# Incorrect domain name.
INVALIDPARAMETER_ILLEGALDOMAIN = 'InvalidParameter.IllegalDomain'

# Incorrect top-level domain name.
INVALIDPARAMETER_ILLEGALDOMAINTLD = 'InvalidParameter.IllegalDomainTld'

# Invalid PTR record.
INVALIDPARAMETER_ILLEGALPTRRECORD = 'InvalidParameter.IllegalPTRRecord'

# Invalid record.
INVALIDPARAMETER_ILLEGALRECORD = 'InvalidParameter.IllegalRecord'

# Invalid record value.
INVALIDPARAMETER_ILLEGALRECORDVALUE = 'InvalidParameter.IllegalRecordValue'

# Invalid VPC.
INVALIDPARAMETER_ILLEGALVPCINFO = 'InvalidParameter.IllegalVpcInfo'

# The MX value must be a multiple of 5 between 5 and 50.
INVALIDPARAMETER_INVALIDMX = 'InvalidParameter.InvalidMX'

# The number of round-robin DNS AAAA records exceeds 50.
INVALIDPARAMETER_RECORDAAAACOUNTEXCEED = 'InvalidParameter.RecordAAAACountExceed'

# The number of round-robin DNS A records exceeds 50.
INVALIDPARAMETER_RECORDACOUNTEXCEED = 'InvalidParameter.RecordACountExceed'

# The number of round-robin DNS CNAME records exceeds 50.
INVALIDPARAMETER_RECORDCNAMECOUNTEXCEED = 'InvalidParameter.RecordCNAMECountExceed'

# Records conflict.
INVALIDPARAMETER_RECORDCONFLICT = 'InvalidParameter.RecordConflict'

# The number of records exceeds the limit.
INVALIDPARAMETER_RECORDCOUNTEXCEED = 'InvalidParameter.RecordCountExceed'

# The record already exists.
INVALIDPARAMETER_RECORDEXIST = 'InvalidParameter.RecordExist'

# The number of record levels exceeds the limit.
INVALIDPARAMETER_RECORDLEVELEXCEED = 'InvalidParameter.RecordLevelExceed'

# The number of round-robin DNS MX records exceeds 50.
INVALIDPARAMETER_RECORDMXCOUNTEXCEED = 'InvalidParameter.RecordMXCountExceed'

# The record does not exist.
INVALIDPARAMETER_RECORDNOTEXIST = 'InvalidParameter.RecordNotExist'

# The number of round-robin DNS records exceeds the limit.
INVALIDPARAMETER_RECORDROLLLIMITCOUNTEXCEED = 'InvalidParameter.RecordRolllimitCountExceed'

# The number of round-robin DNS TXT records exceeds 10.
INVALIDPARAMETER_RECORDTXTCOUNTEXCEED = 'InvalidParameter.RecordTXTCountExceed'

# The current record type does not support weight.
INVALIDPARAMETER_RECORDUNSUPPORTWEIGHT = 'InvalidParameter.RecordUnsupportWeight'

# The VPC has been bound to another domain.
INVALIDPARAMETER_VPCBINDED = 'InvalidParameter.VpcBinded'

# The VPC has been associated with the same primary domain.
INVALIDPARAMETER_VPCBINDEDMAINDOMAIN = 'InvalidParameter.VpcBindedMainDomain'

# The number of PTR records associated with the VPC has reached the limit.
INVALIDPARAMETER_VPCPTRZONEBINDEXCEED = 'InvalidParameter.VpcPtrZoneBindExceed'

# The domain does not exist.
INVALIDPARAMETER_ZONENOTEXISTS = 'InvalidParameter.ZoneNotExists'

# Incorrect parameter value.
INVALIDPARAMETERVALUE = 'InvalidParameterValue'

# This is a reserved domain name and cannot be created.
INVALIDPARAMETERVALUE_RESERVEDDOMAIN = 'InvalidParameterValue.ReservedDomain'

# The quota limit is exceeded.
LIMITEXCEEDED = 'LimitExceeded'

# Exceeded the custom TLD quota.
LIMITEXCEEDED_TLDOUTOFLIMIT = 'LimitExceeded.TldOutOfLimit'

# The number of private domains using the custom TLD exceeds the total quota.
LIMITEXCEEDED_TLDOUTOFRANGE = 'LimitExceeded.TldOutOfRange'

# Missing parameter.
MISSINGPARAMETER = 'MissingParameter'

# The operation was denied.
OPERATIONDENIED = 'OperationDenied'

# The number of requests exceeds the frequency limit.
REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'

# The resource is in use.
RESOURCEINUSE = 'ResourceInUse'

# Insufficient resource.
RESOURCEINSUFFICIENT = 'ResourceInsufficient'

# The resource does not exist.
RESOURCENOTFOUND = 'ResourceNotFound'

# The Private DNS service is not activated.
RESOURCENOTFOUND_SERVICENOTSUBSCRIBED = 'ResourceNotFound.ServiceNotSubscribed'

# The resource is unavailable.
RESOURCEUNAVAILABLE = 'ResourceUnavailable'

# The TLD value-added package expired.
RESOURCEUNAVAILABLE_TLDPACKAGEEXPIRED = 'ResourceUnavailable.TldPackageExpired'

# The resources have been sold out.
RESOURCESSOLDOUT = 'ResourcesSoldOut'

# Unauthorized operation.
UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'

# Role not authorized.
UNAUTHORIZEDOPERATION_ROLEUNAUTHORIZED = 'UnauthorizedOperation.RoleUnAuthorized'

# Unverified user.
UNAUTHORIZEDOPERATION_UNAUTHORIZEDACCOUNT = 'UnauthorizedOperation.UnauthorizedAccount'

# Unknown parameter.
UNKNOWNPARAMETER = 'UnknownParameter'

# Unsupported operation.
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# Account not bound.
UNSUPPORTEDOPERATION_ACCOUNTNOTBOUND = 'UnsupportedOperation.AccountNotBound'



# -*- coding: utf8 -*-
# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


# CAM signature/authentication error.
AUTHFAILURE = 'AuthFailure'

# Operation failed.
FAILEDOPERATION = 'FailedOperation'

# Failed to create the delivery target. Please check the function status.
FAILEDOPERATION_CREATETRIGGER = 'FailedOperation.CreateTrigger'

# Failed to delete the connector. Please check the resource status.
FAILEDOPERATION_DELETECONNECTION = 'FailedOperation.DeleteConnection'

# Failed to delete the rule. Please make sure the resource exists, and the status is normal.
FAILEDOPERATION_DELETERULE = 'FailedOperation.DeleteRule'

# 
FAILEDOPERATION_ERRORFILTER = 'FailedOperation.ErrorFilter'

# 
FAILEDOPERATION_REGISTERCLSSERVICE = 'FailedOperation.RegisterCLSService'

# ServiceError: operation failed. Please check the resource information.
FAILEDOPERATION_SERVICEERROR = 'FailedOperation.ServiceError'

# Failed to update the connector. Please make sure the resource exists, and the status is normal.
FAILEDOPERATION_UPDATECONNECTION = 'FailedOperation.UpdateConnection'

# Failed to update the rule. Please make sure the resource exists, and the status is normal.
FAILEDOPERATION_UPDATERULE = 'FailedOperation.UpdateRule'

# Internal error.
INTERNALERROR = 'InternalError'

# An error occurred while processing the service. Please try again later. If the problem persists, please contact the smart customer service or submit a ticket.
INTERNALERROR_OSSEXCEPTION = 'InternalError.OssException'

# An error occurred while processing the service. Please try again later. If the problem persists, please contact the smart customer service or submit a ticket.
INTERNALERROR_SYSTEM = 'InternalError.System'

# Incorrect parameter.
INVALIDPARAMETER = 'InvalidParameter'

# 
INVALIDPARAMETER_ENABLEAPIGATEWAY = 'InvalidParameter.EnableAPIGateway'

# `Payload` does not conform to the specification. Please fix it and try again.
INVALIDPARAMETER_PAYLOAD = 'InvalidParameter.Payload'

# The `AMPParams` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_AMPPARAMS = 'InvalidParameterValue.AMPParams'

# The `BatchEventCount` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_BATCHEVENTCOUNT = 'InvalidParameterValue.BatchEventCount'

# The `BatchTimeout` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_BATCHTIMEOUT = 'InvalidParameterValue.BatchTimeout'

# The CKafka parameter is invalid. Please check and try again. 
INVALIDPARAMETERVALUE_CKAFKATARGETPARAMS = 'InvalidParameterValue.CKafkaTargetParams'

# The `CallbackType` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_CALLBACKTYPE = 'InvalidParameterValue.CallbackType'

# The `CallbackWeComURL` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_CALLBACKWECOMURL = 'InvalidParameterValue.CallbackWeComURL'

# The `ConnectionDescription` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_CONNECTIONDESCRIPTION = 'InvalidParameterValue.ConnectionDescription'

# The `ConnectionId` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_CONNECTIONID = 'InvalidParameterValue.ConnectionId'

# The `ConnectionName` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_CONNECTIONNAME = 'InvalidParameterValue.ConnectionName'

# 
INVALIDPARAMETERVALUE_DTSPARAMS = 'InvalidParameterValue.DTSParams'

# The dead letter queue parameter is invalid. Please check and try again.
INVALIDPARAMETERVALUE_DEADLETTERCONFIG = 'InvalidParameterValue.DeadLetterConfig'

# The `Description` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_DESCRIPTION = 'InvalidParameterValue.Description'

# The `EventBusId` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_EVENTBUSID = 'InvalidParameterValue.EventBusId'

# The `EventBusName` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_EVENTBUSNAME = 'InvalidParameterValue.EventBusName'

# The `EventPattern` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_EVENTPATTERN = 'InvalidParameterValue.EventPattern'

# 
INVALIDPARAMETERVALUE_EVENTTRACECONFIG = 'InvalidParameterValue.EventTraceConfig'

# The `Filters` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_FILTERS = 'InvalidParameterValue.Filters'

# The `InvalidApiRequestConfig` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_INVALIDAPIREQUESTCONFIG = 'InvalidParameterValue.InvalidApiRequestConfig'

# 
INVALIDPARAMETERVALUE_INVALIDFILTERRULE = 'InvalidParameterValue.InvalidFilterRule'

# 
INVALIDPARAMETERVALUE_INVALIDPATTERN = 'InvalidParameterValue.InvalidPattern'

# The `Limit` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_LIMIT = 'InvalidParameterValue.Limit'

# 
INVALIDPARAMETERVALUE_LINKMODE = 'InvalidParameterValue.LinkMode'

# The `NoticeReceiverChannel` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_NOTICERECEIVERCHANNEL = 'InvalidParameterValue.NoticeReceiverChannel'

# The `NoticeReceiverTimeWindow` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_NOTICERECEIVERTIMEWINDOW = 'InvalidParameterValue.NoticeReceiverTimeWindow'

# The `NoticeReceiverUserIds` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_NOTICERECEIVERUSERIDS = 'InvalidParameterValue.NoticeReceiverUserIds'

# The `NoticeReceiverUserType` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_NOTICERECEIVERUSERTYPE = 'InvalidParameterValue.NoticeReceiverUserType'

# The `Offset` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_OFFSET = 'InvalidParameterValue.Offset'

# The `Order` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_ORDER = 'InvalidParameterValue.Order'

# The `OrderBy` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_ORDERBY = 'InvalidParameterValue.OrderBy'

# The `Qualifier` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_QUALIFIER = 'InvalidParameterValue.Qualifier'

# The `RuleId` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_RULEID = 'InvalidParameterValue.RuleId'

# The `RuleName` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_RULENAME = 'InvalidParameterValue.RuleName'

# The `TargetDescription` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_TARGETDESCRIPTION = 'InvalidParameterValue.TargetDescription'

# The `TargetId` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_TARGETID = 'InvalidParameterValue.TargetId'

# The data transformation parameter is invalid. Please check and try again.
INVALIDPARAMETERVALUE_TRANSFORMATIONID = 'InvalidParameterValue.TransformationID'

# Failed to create the data transformation task: The parameter is invalid. Please check and try again.
INVALIDPARAMETERVALUE_TRANSFORMATIONS = 'InvalidParameterValue.Transformations'

# The `Type` value does not conform to the specification. Please fix it and try again.
INVALIDPARAMETERVALUE_TYPE = 'InvalidParameterValue.Type'

# The `Connection` quantity has reached the upper limit. You can submit a ticket to increase it.
LIMITEXCEEDED_CONNECTION = 'LimitExceeded.Connection'

# The `EventBus` quantity has reached the upper limit. You can submit a ticket to increase it.
LIMITEXCEEDED_EVENTBUS = 'LimitExceeded.EventBus'

# 
LIMITEXCEEDED_INSUFFICIENTBALANCE = 'LimitExceeded.InsufficientBalance'

# The `Logset` quantity has reached the upper limit. You can submit a ticket to increase it.
LIMITEXCEEDED_LOGSET = 'LimitExceeded.Logset'

# The `RouteOverLimit` quantity has reached the upper limit. You can submit a ticket to increase it.
LIMITEXCEEDED_ROUTEOVERLIMIT = 'LimitExceeded.RouteOverLimit'

# The `Rule` quantity has reached the upper limit. You can submit a ticket to increase it.
LIMITEXCEEDED_RULE = 'LimitExceeded.Rule'

# The `Target` quantity has reached the upper limit. You can submit a ticket to increase it.
LIMITEXCEEDED_TARGET = 'LimitExceeded.Target'

# Failed to create the delivery target, as the number of function triggers has reached the limit. You can submit a ticket to increase it.
LIMITEXCEEDED_TRIGGER = 'LimitExceeded.Trigger'

# Failed to create the delivery target, as it was detected that the current account did not exist. Please check your account status.
OPERATIONDENIED_ACCOUNTNOTEXISTS = 'OperationDenied.AccountNotExists'

# You cannot create a CLS event target based on the default EventBridge logset in the custom event bus.
OPERATIONDENIED_DEFAULTCLSRESOURCEUNSUPPORTED = 'OperationDenied.DefaultCLSResourceUnsupported'

# The operation failed, as the resource could not be modified or deleted.
OPERATIONDENIED_RESOURCEIMMUTABLE = 'OperationDenied.ResourceImmutable'

# The current user account type does not support this operation. Please submit a ticket. 
OPERATIONDENIED_UNSUPPORTEDOPERATION = 'OperationDenied.UnsupportedOperation'

# The default Tencent Cloud service event bus cannot be created repeatedly in the same region.
RESOURCEINUSE_DEFAULTEVENTBUS = 'ResourceInUse.DefaultEventBus'

# There are rules or connectors under the event bus, so it cannot be deleted. Please delete all rules and connectors and try again.
RESOURCEINUSE_EVENTBUS = 'ResourceInUse.EventBus'

# There are targets under the rule, so it cannot be deleted. Please delete all targets and try again.
RESOURCEINUSE_RULE = 'ResourceInUse.Rule'

# The resource does not exist.
RESOURCENOTFOUND = 'ResourceNotFound'

# The specified `Connection` was not found. Please create it and try again.
RESOURCENOTFOUND_CONNECTION = 'ResourceNotFound.Connection'

# The specified event bus was not found. Please create it and try again.
RESOURCENOTFOUND_EVENTBUS = 'ResourceNotFound.EventBus'

# The specified `Function` was not found. Please create it and try again.
RESOURCENOTFOUND_FUNCTION = 'ResourceNotFound.Function'

# Failed to delete the connector, as the specified API was not found.
RESOURCENOTFOUND_INVALIDAPI = 'ResourceNotFound.InvalidApi'

# The connector operation failed, as the specified API Gateway service was not found.
RESOURCENOTFOUND_INVALIDSERVICE = 'ResourceNotFound.InvalidService'

# Failed to create the delivery target, as the specified namespace was not found. Please create it and try again.
RESOURCENOTFOUND_NAMESPACE = 'ResourceNotFound.Namespace'

# The specified service role was not found. Please create it and try again.
RESOURCENOTFOUND_ROLE = 'ResourceNotFound.Role'

# The specified `Rule` was not found. Please create it and try again.
RESOURCENOTFOUND_RULE = 'ResourceNotFound.Rule'

# The specified `Target` was not found. Please create it and try again.
RESOURCENOTFOUND_TARGET = 'ResourceNotFound.Target'

# The specified task is not found. Please check and try again.
RESOURCENOTFOUND_TRANSFORMATION = 'ResourceNotFound.Transformation'

# Failed to create the delivery target, as the specified service version was not found. Please create it and try again.
RESOURCENOTFOUND_VERSION = 'ResourceNotFound.Version'

# Failed to create the connector, as the current resource was unavailable.
RESOURCEUNAVAILABLE_CONNECTION = 'ResourceUnavailable.Connection'

# Failed to create the delivery target, as the current resource was unavailable.
RESOURCEUNAVAILABLE_TARGET = 'ResourceUnavailable.Target'

# The current account does not have permissions to use EB. Please log in to the CAM console for authorization.
UNAUTHORIZEDOPERATION_CAM = 'UnauthorizedOperation.CAM'

# Unsupported operation.
UNSUPPORTEDOPERATION = 'UnsupportedOperation'

# The connector operation failed, as the API did not support the current operation.
UNSUPPORTEDOPERATION_INVALIDACTION = 'UnsupportedOperation.InvalidAction'

# Failed to create the connector, as the current backend service type was not supported.
UNSUPPORTEDOPERATION_INVALIDENDPOINTTYPE = 'UnsupportedOperation.InvalidEndpointType'
